@@ -3,6 +3,8 @@ package WizTestSettings;
 use strict;
 use warnings;
 
+our $VERSION = do { my @r = ( q$Revision: 1.2 $ =~ /\d+/g ); sprintf "%d." . "%03d" x $#r, @r };
+
 =head1 NAME
 
 Tk::Wizard::Testing - used in wizard testing
@@ -11,36 +13,18 @@ Tk::Wizard::Testing - used in wizard testing
 
 One subroutine, C<add_test_pages>, that adds pages to a wizard.
 
-=head1 VARIABLES
-
-C<$VERSION> should be set to the release version of C<Wizard.pm> for automated tests.
-
 =cut
 
 use Carp;
-
-our $VERSION; # see POD
+use Tk::Wizard;
 
 BEGIN {
-	# Set our version to be the TK::Wizard version to use
-	$VERSION = do { my @r = ( q$Revision: 2.080 $ =~ /\d+/g ); sprintf "%d." . "%03d" x $#r, @r };
-
-	# Require the correct version
-	use lib "../lib";
-	eval 'use Tk::Wizard ' . $VERSION . ' ":old"';
-	die $@ if $@;
-
-	# Log l4p is we have it
 	eval { require Log::Log4perl; };
-	# No l4p - add stubs
-	if ($@) {
+	if($@) {
+		print "Log::Log4perl not installed - stubbing.\n";
 		no strict qw(refs);
 		*{"main::$_"} = sub { } for qw(DEBUG INFO WARN ERROR FATAL);
-		*{"WizTestSettings::$_"} = sub { } for qw(DEBUG INFO WARN ERROR FATAL);
-	}
-
-	# Have l4p - configure
-	else {
+	} else {
 		no warnings;
 		require Log::Log4perl::Level;
 		Log::Log4perl::Level->import(__PACKAGE__);
@@ -48,19 +32,11 @@ BEGIN {
 
 		if (not Log::Log4perl::initialized()){
 			# my ($fn) = $0 =~ /[^\/]+$/;
-
-			my $log_conf = "log4perl.logger                   	= ERROR, Screen\n";
-
-			if ($Log::Log4Perl::VERSION >= 1.11){
-				$log_conf .= "log4perl.appender.Screen       	= Log::Log4perl::Appender::ScreenColoredLevels\n";
-				$log_conf .= "log4perl.appender.Screen.layout	= PatternLayout::Multiline\n";
-			} else {
-				$log_conf .= "log4perl.appender.Screen        	= Log::Log4perl::Appender::Screen\n";
-				$log_conf .= "log4perl.appender.Screen.layout	= PatternLayout\n";
-			}
-
-			$log_conf .= q[
-				log4perl.appender.Screen.stderr   				= 1
+			my $Log_Conf = q[
+				log4perl.logger                   = TRACE, Screen
+				log4perl.appender.Screen          = Log::Log4perl::Appender::ScreenColoredLevels
+				log4perl.appender.Screen.stderr   = 1
+				log4perl.appender.Screen.layout   = PatternLayout::Multiline
 				log4perl.appender.Screen.layout.ConversionPattern = %7p | %-70m | %M %L%n
 			];
 
@@ -70,7 +46,7 @@ BEGIN {
 			#	log4perl.appender.File.autoflush  = 1
 			#	log4perl.appender.File.layout     = PatternLayout::Multiline
 			#	log4perl.appender.File.layout.ConversionPattern = %7p | %-70m | %M %L%n
-			Log::Log4perl->init( \$log_conf );
+			Log::Log4perl->init( \$Log_Conf );
 		}
 	}
 }
@@ -78,11 +54,11 @@ BEGIN {
 sub add_test_pages {
 	my ($wiz, $args) = (shift, ref($_[0])? shift : {@_});
 
-    my ( $dir_select, $file_select, $mc1, $mc2, $mc3 );
+    my ( $sDirSelect, $sFileSelect, $mc1, $mc2, $mc3 );
 
-	$args->{-wait} ||= $ENV{TEST_INTERACTIVE}? -1 : 250,
+	$args->{-wait} ||= 250;
 
-    $dir_select = $^O =~ m/MSWin32/i ? 'C:\\' : '/';
+    $sDirSelect = $^O =~ m/MSWin32/i ? 'C:\\' : '/';
 
     $wiz->addPage(
         sub {
@@ -106,26 +82,23 @@ and a reference to this string variable is passed to the addTextFramePage() meth
         -boxedtext  => \$s,
         -background => 'yellow',
     );
-
     $wiz->addDirSelectPage(
         -wait       => $args->{-wait},
         -title      => "Tester DirSelect Page Title ($wiz->{-style} style)",
         -subtitle   => "Tester DirSelect Page Subtitle ($wiz->{-style} style)",
         -text       => "This is the Text of the Tester DirSelect Page ($wiz->{-style} style)",
         -nowarnings => 88,
-        -variable   => \$dir_select,
+        -variable   => \$sDirSelect,
         -background => 'yellow',
     );
-
     $wiz->addFileSelectPage(
         -wait       => $args->{-wait},
         -title      => "Tester FileSelect Page Title ($wiz->{-style} style)",
         -subtitle   => "Tester FileSelect Page Subtitle ($wiz->{-style} style)",
         -text       => "This is the Text of the Tester FileSelect Page ($wiz->{-style} style)",
-        -variable   => \$file_select,
+        -variable   => \$sFileSelect,
         -background => 'yellow',
     );
-
     $wiz->addMultipleChoicePage(
         -wait     => $args->{-wait},
         -title    => "Tester Multiple-Choice Page Title ($wiz->{-style} style)",
@@ -153,7 +126,6 @@ and a reference to this string variable is passed to the addTextFramePage() meth
         ],    # -choices
         -background => 'yellow',
     );
-
     $wiz->addTaskListPage(
         -wait     => $args->{-wait},
         -title    => "Tester Task List Page Title ($wiz->{-style} style)",
@@ -168,12 +140,8 @@ and a reference to this string variable is passed to the addTextFramePage() meth
         ],
         -background => 'yellow',
     );
-
     return $wiz;
-}
-
-
-
+}    # new
 
 =head2 Show
 
